enable_vector

Function enable_vector 

pub fn enable_vector()
Enable Vector extension access by setting sstatus.VS to Initial state

This must be called before user space can use vector instructions. The VS field in sstatus controls access to the Vector extension:

  • 00: Off - Vector access causes illegal instruction exception
  • 01: Initial - Vector is enabled with initial state
  • 10: Clean - Vector is enabled, state has not been modified
  • 11: Dirty - Vector is enabled, state has been modified