kernel_switch_in_user_fpu

Function kernel_switch_in_user_fpu 

pub fn kernel_switch_in_user_fpu(vcpu: &mut Vcpu)
Restore user FPU context when resuming a task in the kernel.

This restores the task’s saved context into the architectural registers so subsequent kernel operations (and the eventual user return path) can rely on a consistent state.