pub fn enable_fpu()Expand description
Enable FPU access by setting sstatus.FS to Initial state
This must be called before user space can use floating-point instructions. The FS field in sstatus controls access to the FPU:
- 00: Off - FPU access causes illegal instruction exception
- 01: Initial - FPU is enabled with initial state
- 10: Clean - FPU is enabled, state has not been modified
- 11: Dirty - FPU is enabled, state has been modified